%% Example of ca2+ signals 

function ROI_ca=plotCaSignal(Ca, fs_ca, smooth_value, pre, onset)
    % Function to process and plot Ca2+ signals
    %
    % Inputs:
    % Ca - data of Ca2+ signals 
    % fs_ca - Ca2+ signaling sampling rate 
    % smooth_value - the extent of detrending in the signal 
    % pre - the onset time of baseline 
    % onset - the onset time of light stimulation

    % Detrend the calcium signal
    Ca_detrended = smooth(Ca, smooth_value); 
    
    % Select the baseline of Ca2+ signals
    Ca_baseline = Ca_detrended(onset*fs_ca-pre*fs_ca+1:onset*fs_ca); 
    
    % Calculate the ∆F/F
    ROI_ca = (Ca_detrended - mean(Ca_baseline)) / mean(Ca_baseline);  % (s)-(∆F/F) 
    
    % Create the timeline
    t1 = (1:length(ROI_ca)) / fs_ca; 
    %
    % Onputs:
    % Create a figure
    figure
    plot(t1, ROI_ca, 'HandleVisibility', 'off', 'Color', '#e55709', 'LineWidth', 0.2);
    set(gca, 'TickDir', 'out'); 
    box off
end

% % Example usage
% Ca = ... % your Ca2+ signal data %% the length of showing time is 55 s in our study
% fs_ca = ... % your sampling rate %%  30 Hz in our study
% smooth_value = ... % your smooth value %% default SPAN 5
% pre = ... % your baseline onset time %% We define the Ca2+ signal 5 s before the light as the baseline
% onset = ... % your light stimulation onset time
% 
% plotCaSignal(Ca, fs_ca, smooth_value, pre, onset);